(function(){tinymce.create("tinymce.plugins.PloneInlineStylesPlugin",{init:function(a,b){a.onPreProcess.add(function(c,d){valid=new RegExp("("+c.getParam("valid_inline_styles").replace(/,/g,"|")+")[a-z-]*:[^;]*","igm");tinymce.each(c.dom.select("*",d.node).reverse(),function(e){styleAttr=(e.getAttribute("style"))?e.getAttribute("style"):"";style=(tinymce.is(styleAttr,"object"))?(styleAttr.cssText!="undefined")?styleAttr.cssText.toLowerCase():"":styleAttr.toLowerCase();validStyles=style.match(valid);style="";if(validStyles){for(j=0;j<validStyles.length;j++){style+=validStyles[j]+"; "}}if(style.length>0){c.dom.setAttrib(e,"style",style)}else{c.dom.setAttrib(e,"style","")}})})},getInfo:function(){return{longname:"Plone inline styles",author:"Rob Gietema",authorurl:"http://plone.org",infourl:"http://plone.org/products/tinymce",version:tinymce.majorVersion+"."+tinymce.minorVersion}}});tinymce.PluginManager.add("ploneinlinestyles",tinymce.plugins.PloneInlineStylesPlugin)})();