tinyMCE.addI18n('id.emotions_dlg',{cry:"Menangis",cool:"Keren",desc:"Emosi",title:"Sisipkan Emosi",yell:"Bersorak",wink:"Berkedip",undecided:"Bimbang","tongue_out":"Menjulurkan Lidah",surprised:"Terkejut",smile:"Senyum",sealed:"Tertutup","money_mouth":"Mulut Uang",laughing:"Tertawa",kiss:"Mencium",innocent:"Tidak Bersalah",frown:"Mengerutkan Dahi","foot_in_mouth":"Kaki di mulut",embarassed:"Malu",usage:"Gunakan panah kiri dan kanan untuk melakukan navigasi."});