tinyMCE.addI18n('ko.media_dlg',{list:"\ubaa9\ub85d",file:"\ud30c\uc77c/URL",advanced:"\uace0\uae09",general:"\uc77c\ubc18",title:"\ubbf8\ub514\uc5b4 \uc0bd\uc785/\ud3b8\uc9d1","align_top_left":"Top left","align_center":"Center","align_left":"Left","align_bottom":"Bottom","align_right":"Right","align_top":"Top","qt_stream_warn":"QT Src \ud544\ub4dc\uc5d0 \uc2a4\ud2b8\ub9ac\ubc0d rtsp \ub9ac\uc18c\uc2a4\ub97c \ucd94\uac00\ud574\uc57c \ud569\ub2c8\ub2e4.\n\ub610\ub294 Src \ud544\ub4dc\uc5d0 \ube44 \uc2a4\ud2b8\ub9ac\ubc0d \ubc84\uc804\uc744 \ucd94\uac00\ud574\uc57c \ud569\ub2c8\ub2e4.",qtsrc:"QT Src",progress:"\uc9c4\ud589",sound:"\uc18c\ub9ac",swstretchvalign:"\uac00\ub85c\ub85c \ub298\ub9ac\uae30",swstretchhalign:"\uc138\ub85c\ub85c \ub298\ub9ac\uae30",swstretchstyle:"Stretch style",scriptcallbacks:"Script callbacks","align_top_right":"\uc0c1\ub2e8 \uc624\ub978\ucabd",uimode:"UI \ubaa8\ub4dc",rate:"\ube44\uc728",playcount:"\uc2e4\ud589 \ud68c\uc218",defaultframe:"\uae30\ubcf8 \ud504\ub808\uc784",currentposition:"\ud604\uc7ac \uc704\uce58",currentmarker:"\ud604\uc7ac \ud45c\uc2dc",captioningid:"\uc790\ub9c9 id",baseurl:"\uae30\ubcf8 URL",balance:"\uade0\ud615",windowlessvideo:"\ud14c\ub450\ub9ac\uc5c6\uc570",stretchtofit:"\uc54c\ub9de\uac8c \ub9de\ucd94\uae30",mute:"\ubb34\uc74c",invokeurls:"Invoke URLs",fullscreen:"\uc804\uccb4\ud654\uba74",enabled:"\ud65c\uc131",autostart:"\uc790\ub3d9 \uc2dc\uc791",volume:"\ubcfc\ub968",target:"\ud0c0\uac9f",qtsrcchokespeed:"Choke speed",href:"Href",endtime:"End time",starttime:"Start time",enablejavascript:"JavaScript\ub97c \ud5c8\uac00",correction:"\uc633\ubc14\ub974\uc9c0 \uc54a\uc74c",targetcache:"\ud0c0\uac9f \uce90\uc26c",playeveryframe:"\ubaa8\ub4e0 \ud504\ub808\uc784 \uc7ac\uc0dd",kioskmode:"Kiosk mode",controller:"Controller",menu:"\uba54\ub274 \ud45c\uc2dc",loop:"\uc5f0\uc18d \uc7ac\uc0dd",play:"\uc790\ub3d9 \uc7ac\uc0dd",hspace:"\uc88c\uc6b0 \uc5ec\ubc31",vspace:"\uc0c1\ud558 \uc5ec\ubc31","class_name":"Class",name:"Name",id:"Id",type:"\ud0c0\uc785",size:"\ud06c\uae30",preview:"\ubbf8\ub9ac\ubcf4\uae30","constrain_proportions":"\uc885\ud6a1\ube44 \uc720\uc9c0",controls:"Controls",numloop:"Num loops",console:"Console",cache:"Cache",autohref:"\uc790\ub3d9 HREF",liveconnect:"SWLiveConnect",flashvars:"Flashvars",base:"Base",bgcolor:"Background",wmode:"WMode",salign:"SAlign",align:"\uc815\ub82c",scale:"\uc2a4\ucf00\uc77c",quality:"\ud488\uc9c8",shuffle:"Shuffle",prefetch:"Prefetch",nojava:"No java",maintainaspect:"Maintain aspect",imagestatus:"Image status",center:"Center",autogotourl:"\uc790\ub3d9\uc73c\ub85c URL\ub85c \uac00\uae30","shockwave_options":"Shockwave \uc635\uc158","rmp_options":"Real media player \uc635\uc158","wmp_options":"\uc708\ub3c4\uc6b0\uc988 \ubbf8\ub514\uc5b4 \ud50c\ub808\uc774\uc5b4 \uc635\uc158","qt_options":"\ud035\ud0c0\uc784 \uc635\uc158","flash_options":"\ud50c\ub798\uc26c \uc635\uc158",hidden:"Hidden","align_bottom_left":"Bottom left","align_bottom_right":"Bottom right",flash:"flash",quicktime:"\ud035\ud0c0\uc784","embedded_audio_options":"\uc0bd\uc785\ub41c \uc624\ub514\uc624 \uc635\uc158",windowsmedia:"\uc708\ub3c4\uc6b0\uc988 \ubbf8\ub514\uc5b4",realmedia:"\ub9ac\uc5bc\ubbf8\ub514\uc5b4",shockwave:"\uc1fd\uc6e8\uc774\ube0c(shockwave)",audio:"\uc624\ub514\uc624",video:"\ube44\ub514\uc624(Video)","html5_video_options":"HTML5 \ube44\ub514\uc624 \uc635\uc158",altsource1:"\ub300\uccb4 \uc18c\uc2a4 1",altsource2:"\ub300\uccb4 \uc18c\uc2a4 2",preload:"\ubbf8\ub9ac\ubd88\ub7ec\uc624\uae30",poster:"Poster \uc18d\uc131",source:"\uc18c\uc2a4","html5_audio_options":"\uc624\ub514\uc624 \uc635\uc158","preload_none":"\ubbf8\ub9ac\ubd88\ub7ec\uc624\uc9c0 \uc54a\uae30","preload_metadata":"\ub3d9\uc601\uc0c1 \uba54\ud0c0\ub370\uc774\ud130 \uc608\uce21","preload_auto":"\uc0ac\uc6a9\uc790 \ube0c\ub77c\uc6b0\uc800\uc5d0 \ub530\ub77c\uc11c",iframe:"iframe",embeddedaudio:"\ub0b4\uc7a5\uc74c\uc131"});