tinyMCE.addI18n('id.advanced',{"underline_desc":"Garis Bawah (Ctrl U)","italic_desc":"Cetak Miring (Ctrl I)","bold_desc":"Cetak Tebal (Ctrl B)",dd:"Definisi Deskripsi",dt:"Definisi Aturan",samp:"Contoh Kode",code:"Kode",blockquote:"Blockquote",h6:"Heading 6",h5:"Heading 5",h4:"Heading 4",h3:"Heading 3",h2:"Heading 2",h1:"Heading 1",pre:"Preformatted",address:"Alamat",div:"Div",paragraph:"Paragraf",block:"Format",fontdefault:"Jenis Huruf","font_size":"Ukuran Huruf","style_select":"Gaya","more_colors":"Warna Lain","toolbar_focus":"Jump to tool buttons - Alt+Q, Jump to editor - Alt-Z, Jump to element path - Alt-X",newdocument:"Yakin untuk menghapus semua konten?",path:"Path","clipboard_msg":"Copy/Cut/Paste tidak tersedia pada Mozilla dan Firefox.\nButuh info selengkapnya?","blockquote_desc":"Blockquote","help_desc":"Bantuan","newdocument_desc":"Dokumen Baru","image_props_desc":"Properti Gambar","paste_desc":"Tempel (Ctrl V)","copy_desc":"Salin (Ctrl C)","cut_desc":"Potong (Ctrl X)","anchor_desc":"Sisipkan/Ubah Anchor","visualaid_desc":"Toggle guidelines/invisible elements","charmap_desc":"Sisipkan Karakter Spesial","backcolor_desc":"Piliha Warna Latar Belakang","forecolor_desc":"Pilih Warna Teks","custom1_desc":"Deskripsi disini","removeformat_desc":"Remove formatting","hr_desc":"Insert horizontal ruler","sup_desc":"Superscript","sub_desc":"Subscript","code_desc":"Ubah Sumber HTML","cleanup_desc":"Cleanup messy code","image_desc":"Sisipkan/Ubah Gambar","unlink_desc":"Hapus Tautan","link_desc":"Buat/Ubah Tautan","redo_desc":"Mengulangi (Ctrl Y)","undo_desc":"Batal (Ctrl Z)","indent_desc":"Spasi","outdent_desc":"Outdent","numlist_desc":"Buat/Hapus Daftar dengan Penomoran","bullist_desc":"Buat/Hapus Daftar dengan Simbol","justifyfull_desc":"Rata Semua","justifyright_desc":"Rata Kanan","justifycenter_desc":"Rata Tengah","justifyleft_desc":"Rata Kiri","striketrough_desc":"Strikethrough","help_shortcut":"Tekan ALT-F10 untuk toolbar. TekanALT-0 Untuk bantuan","rich_text_area":"Rich Text Area","shortcuts_desc":"Akses Bantuan",toolbar:"Gunakan tombol panah untuk memilih fungsi","anchor_delta_height":"","anchor_delta_width":"","charmap_delta_height":"","charmap_delta_width":"","colorpicker_delta_height":"","colorpicker_delta_width":"","link_delta_height":"","link_delta_width":"","image_delta_height":"","image_delta_width":""});