/* CSS file for cell dialog in the table plugin */

#content.dialog-wrapper {
    font-size: 80%;
}

.panel_wrapper div.current {
	height: 160px;
}

.advfield {
	width: 200px;
}

#action {
	margin-bottom: 3px;
}

#class {
	width: 150px;
}

.hiddenset { display: none; }

.width-height {
    display: inline-block;
    *display: inline;
    zoom:1;
}