tinyMCE.addI18n('id.advanced_dlg',{"link_list":"Daftar Tautan","link_is_external":"URL yang Anda sisipkan tampaknya tautan eksternal, Anda ingin menambahkan awalan \'http://\'?","link_is_email":"URL yang Anda sisipkan tampaknya e-mail, Anda ingin menambahkan awalan \'mailto:\'?","link_titlefield":"Judul","link_target_blank":"Buka tautan pada jendela baru","link_target_same":"Buka tautan pada jendela yang sama","link_target":"Target","link_url":"Tautan URL","link_title":"Buat/Ubah Tautan","image_align_right":"Kanan","image_align_left":"Kiri","image_align_textbottom":"Text bottom","image_align_texttop":"Text top","image_align_bottom":"Bawah","image_align_middle":"Tengah","image_align_top":"Atas","image_align_baseline":"Baseline","image_align":"Perataan","image_hspace":"Spasi Horizontal","image_vspace":"Spasi Vertikal","image_dimensions":"Dimensi","image_alt":"Deskripsi Gambar","image_list":"Daftar Gambar","image_border":"Border","image_src":"URL Gambar","image_title":"Masukkan/Ubah Gambar","charmap_title":"Pilih custom character","colorpicker_name":"Nama:","colorpicker_color":"Warna:","colorpicker_named_title":"Named colors","colorpicker_named_tab":"Named","colorpicker_palette_title":"Palette colors","colorpicker_palette_tab":"Palette","colorpicker_picker_title":"Color picker","colorpicker_picker_tab":"Picker","colorpicker_title":"Pilih sebuah warna","code_wordwrap":"Word wrap","code_title":"HTML Source Editor","anchor_name":"Anchor name","anchor_title":"Insert/edit anchor","about_loaded":"Loaded plugins","about_version":"Versi","about_author":"Penulis","about_plugin":"Plugin","about_plugins":"Plugins","about_license":"Lisensi","about_help":"Bantuan","about_general":"Tentang","about_title":"Tentang TinyMCE","charmap_usage":"Gunakan arah kiri dan kanan untuk navigasi.","anchor_invalid":"Tolong spesifikkan nama anchor yang valid.","accessibility_help":"Bantuan Aksesibilitas","accessibility_usage_title":"Penggunaan Secara Umum","invalid_color_value":"Nilai warna tidak valid"});