tinyMCE.addI18n('id.media_dlg',{list:"Daftar",file:"Arsip/URL",advanced:"Lebih(Advanced)",general:"Umum",title:"Sisipkan/Ubah \'Embedded\' Media","align_top_left":"Atas Kiri","align_center":"Tengah","align_left":"Kiri","align_bottom":"Bawah","align_right":"Kanan","align_top":"Atas","qt_stream_warn":"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",qtsrc:"QT Src",progress:"Proses",sound:"Suara",swstretchvalign:"Stretch V-Align",swstretchhalign:"Stretch H-Align",swstretchstyle:"Stretch style",scriptcallbacks:"Script callbacks","align_top_right":"Atas Kanan",uimode:"UI Mode",rate:"Rate",playcount:"Play count",defaultframe:"Default frame",currentposition:"Current position",currentmarker:"Current marker",captioningid:"Captioning id",baseurl:"Base URL",balance:"Balance",windowlessvideo:"Windowless video",stretchtofit:"Stretch to fit",mute:"Mute",invokeurls:"Invoke URLs",fullscreen:"Fullscreen",enabled:"Memperbolehkan",autostart:"Otomatis Mulai",volume:"Volume",target:"Target",qtsrcchokespeed:"Choke speed",href:"Href",endtime:"Waktu Selesai",starttime:"Waktu Mulai",enablejavascript:"Memperbolehkan Javascript",correction:"Tanpa/Tidak ada Koreksi",targetcache:"Target cache",playeveryframe:"Mainkan Setiap Bingkai",kioskmode:"Kiosk mode",controller:"Pengontrol",menu:"Tampilkan Menu",loop:"Pengulangan",play:"Otomatis Putar",hspace:"H-Space",vspace:"V-Space","class_name":"Class",name:"Name",id:"Id",type:"Type",size:"Dimensions",preview:"Peninjauan","constrain_proportions":"Constrain proportions",controls:"Kontrol",numloop:"Num loops",console:"Console",cache:"Cache",autohref:"AutoHREF",liveconnect:"SWLiveConnect",flashvars:"Flashvars",base:"Base",bgcolor:"Latar Belakang",wmode:"WMode",salign:"SAlign",align:"Perataan",scale:"Scale",quality:"Kualitas",shuffle:"Shuffle",prefetch:"Prefetch",nojava:"No java",maintainaspect:"Maintain aspect",imagestatus:"Status Gambar",center:"Center",autogotourl:"Otomatis pergi ke URL","shockwave_options":"Shockwave options","rmp_options":"Real media player options","wmp_options":"Windows media player options","qt_options":"Quicktime options","flash_options":"Flash options",hidden:"Sembunyi","align_bottom_left":"Bawah Kiri","align_bottom_right":"Bawah kanan",flash:"",quicktime:"","embedded_audio_options":"Pilihan Embedded Audio",windowsmedia:"",realmedia:"",shockwave:"",audio:"",video:"","html5_video_options":"Pilihan HTML5 Video",altsource1:"Alternatif Sumber 1",altsource2:"Alternatif Sumber 2",preload:"",poster:"Poster",source:"Sumber","html5_audio_options":"Pilihan Audio","preload_none":"Jangan di-Preload","preload_metadata":"Metadata preload video","preload_auto":"Biarkan browser pengguna menentukan",iframe:"",embeddedaudio:""});